@@ -2453,51 +2453,66 @@ async function handler(event, context) {
         try {
           switch (objectType) {
             case "Component": {
-              const result = await ib.listComponents({
-                filters: [{
-                  name: "name",
-                  values: [objectName]
-                }]
-              }).promise();
-              allVersions = result.componentVersionList.map((i) => i.version || "1.0.0");
+              let result = {};
+              do {
+                result = await ib.listComponents({
+                  filters: [{
+                    name: "name",
+                    values: [objectName]
+                  }],
+                  nextToken: result.nextToken
+                }).promise();
+                allVersions = allVersions.concat(result.componentVersionList.map((i) => i.version || "1.0.0"));
+              } while (result.nextToken);
               break;
             }
             case "ImageRecipe": {
-              const result = await ib.listImageRecipes({
-                filters: [{
-                  name: "name",
-                  values: [objectName]
-                }]
-              }).promise();
-              allVersions = result.imageRecipeSummaryList.map((i) => {
-                var _a;
-                return ((_a = i.arn) == null ? void 0 : _a.split("/").pop()) || "1.0.0";
-              });
+              let result = {};
+              do {
+                result = await ib.listImageRecipes({
+                  filters: [{
+                    name: "name",
+                    values: [objectName]
+                  }],
+                  nextToken: result.nextToken
+                }).promise();
+                allVersions = allVersions.concat(result.imageRecipeSummaryList.map((i) => {
+                  var _a;
+                  return ((_a = i.arn) == null ? void 0 : _a.split("/").pop()) || "1.0.0";
+                }));
+              } while (result.nextToken);
               break;
             }
             case "ContainerRecipe": {
-              const result = await ib.listContainerRecipes({
-                filters: [{
-                  name: "name",
-                  values: [objectName]
-                }]
-              }).promise();
-              allVersions = result.containerRecipeSummaryList.map((i) => {
-                var _a;
-                return ((_a = i.arn) == null ? void 0 : _a.split("/").pop()) || "1.0.0";
-              });
+              let result = {};
+              do {
+                result = await ib.listContainerRecipes({
+                  filters: [{
+                    name: "name",
+                    values: [objectName]
+                  }],
+                  nextToken: result.nextToken
+                }).promise();
+                allVersions = allVersions.concat(result.containerRecipeSummaryList.map((i) => {
+                  var _a;
+                  return ((_a = i.arn) == null ? void 0 : _a.split("/").pop()) || "1.0.0";
+                }));
+              } while (result.nextToken);
               break;
             }
           }
         } catch (e) {
           if (e.code !== "ResourceNotFoundException") {
             throw e;
+          } else {
+            console.log("Resource not found, assuming first version");
           }
         }
         version = (0, import_semver.maxSatisfying)(allVersions, ">=0.0.0");
         if (version === null) {
           version = "1.0.0";
         }
+        console.log(`Found versions ${allVersions} -- latest is ${version}`);
         version = (0, import_semver.inc)(version, "patch");
         if (version === null) {
           throw new Error("Unable to bump version");
